Structs
- Mitmproxy
Flow Wrapper - Wrapper around a parsed mitmproxy flow that implements CapturedRequest.
Functions
- mitmproxy_
heuristic - Heuristic: does this file look like a mitmproxy flow dump? First byte is ASCII digit → likely tnetstring → mitmproxy flow.
- read_
mitmproxy_ dir - read_
mitmproxy_ file - stream_
mitmproxy_ dir - stream_
mitmproxy_ file